darkhistory.spec.transferfunclist.TransferFuncInterps — DarkHistory documentation

# darkhistory.spec.transferfunclist.TransferFuncInterps

class `darkhistory.spec.transferfunclist.` `TransferFuncInterps`(tfInterps, xe_arr)

  Interpolation function over list of TransferFuncList objects.

  Parameters: | TransferFuncInterps : list of TransferFuncInterp objects List of TransferFuncInterp objects to consolidate.
  Attributes: | rs : ndarray Redshift abscissa of the transfer functions. dlnz : float The d ln(1+z) step for the transfer functions. interp_func : function A 2D interpolation function over xe and rs that piece-wise connects the interp_funcs of each member TransferFuncInterp objects

  Methods

  get_tf |

  `__init__`(tfInterps, xe_arr)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(tfInterps, xe_arr) | Initialize self.
  `get_tf`(xe, rs) |

#### Previous topic

darkhistory.spec.transferfunclist.TransferFuncInterp

#### Next topic

darkhistory.spec.transferfunclist.TransferFuncList

### This Page

Show Source